==> GeneR_2.4.0.tar.gz: GeneR/R/segments.R <==
as.segSet <- function(x)
  {
    if(is.null(x))
      return(NULL)
    x <- as.matrix(x)
    x <- c(x,recursive=TRUE)    
    x <- matrix(as.matrix(x),ncol=2)
    if(sum(x[,1] > x[,2]) >0)
      {
        warning("Segments are not correct (begining position > end)")
        return(NULL)
      }
    class(x) <- "segSet"
    return(x)
  }

as.matrix.segSet <- function(x)
  {
    class(x) <- NULL
    return(x)
  }

as.data.frame.segSet <- function(x,row.names = NULL,optional = FALSE,...)
  {
    class(x) <- NULL
    return(as.data.frame(x,row.names = row.names,optional=optional))
  }

plot.segSet <- function(x,...)
  {
    class(x) <- NULL
    plot.globalSeg(as.globalSeg(x),...)
  }

"|.segSet" <- or.segSet <- unionSeg <- function(a,b=NULL,simplify=TRUE,...)
  {

    a <- rbind(a,b)
    if(is.null(a))
      return(NULL)
    
    from <- a[,1]
    to <-   a[,2]    
    ordr <- order(from)
    from <- from[ordr]
    to <- to[ordr]
    n <-  length(from)
    res <- .C("vec_union",
              from=as.double(from),
              to=as.double(to),
              n=as.integer(n),
              flag=integer(n),
              dup=FALSE,
              PACKAGE="GeneR")

    n <- res$n +1
    from <- res$from[1:n]
    to <- res$to[1:n]
    if(!simplify)
      {
        from <- from[res$flag]
        to <- to[res$flag]
        ordr2 <- order(ordr)
        from <- from[ordr2]
        to <- to[ordr2]
      }
    
    return(as.segSet(cbind(from,to)))
  }

"&.segSet" <- and.segSet <- function(a,b=NULL,...)
  {
    if(is.null(b))
      {
        deb <- max(a[,1])
        fin <- min(a[,2])
        if(deb<= fin)
          return(as.segSet(deb,fin))
        else
          return(as.segSet(NULL))
      }

    a <- or.segSet(a)
    b <- or.segSet(b)
    
    orda <- order(a[,1])
    ordb <- order(b[,1])

    
    res <- .C("intersection",
              from0=double(nrow(a)+nrow(b)),
              from1=as.double(a[orda,1]),
              from2=as.double(b[ordb,1]),
              to0=double(nrow(a)+nrow(b)),
              to1=as.double(a[orda,2]),
              to2=as.double(b[ordb,2]),
              n1=as.integer(nrow(a)),
              n2=as.integer(nrow(b)),
              dup=FALSE,
              PACKAGE="GeneR"
              )
    n <- res$n1
    from <- res$from0[1:n]
    to <- res$to0[1:n]
    return(as.segSet(cbind(from,to)))
 
  }


"-.segSet" <- not.segSet <- function(a,b)
  {
    a <- or.segSet(a)
    c <- and.segSet(a,b)
    c <- xorRecouvr(c,a)
    return(as.segSet(c))
  }


Xor.segSet <- function(a,b)
  {
    u <- or.segSet(a,b)
    c <- and.segSet(a,b)
    c <- xorRecouvr(c,u)
    return(as.segSet(c))
  }


#match <- function(...)
#  UseMethod("match")

#match.default <- function(...)
#  base::match(...)

Match <- function(x,a) 
{
  
 .C("num_in_interv",
    num=as.double(x),
    from=as.double(a[,1]),
    to=as.double(a[,2]),
    m=as.integer(length(x)),
    n=as.integer(nrow(a)),
    res=integer(length(x)),
    PACKAGE="GeneR")$res
}

==> GeneR_2.6.0.tar.gz: GeneR/R/segments.R <==
as.segSet <- function(x)
  {
    if(is.null(x))
      return(NULL)
    x <- as.matrix(x)
    x <- c(x,recursive=TRUE)    
    x <- matrix(as.matrix(x),ncol=2)
    if(sum(x[,1] > x[,2]) >0)
      {
        warning("Segments are not correct (begining position > end)")
        return(NULL)
      }
    class(x) <- "segSet"
    return(x)
  }

as.matrix.segSet <- function(x,...)
  {
    class(x) <- NULL
    return(x)
  }

as.data.frame.segSet <- function(x,row.names = NULL,optional = FALSE,...)
  {
    class(x) <- NULL
    return(as.data.frame(x,row.names = row.names,optional=optional))
  }

plot.segSet <- function(x,...)
  {
    class(x) <- NULL
    plot.globalSeg(as.globalSeg(x),...)
  }

"|.segSet" <- or.segSet <- unionSeg <- function(a,b=NULL,simplify=TRUE,...)
  {

    a <- rbind(a,b)
    if(is.null(a))
      return(NULL)
    
    from <- a[,1]
    to <-   a[,2]    
    ordr <- order(from)
    from <- from[ordr]
    to <- to[ordr]
    n <-  length(from)
    res <- .C("vec_union",
              from=as.double(from),
              to=as.double(to),
              n=as.integer(n),
              flag=integer(n),
              dup=FALSE,
              PACKAGE="GeneR")

    n <- res$n +1
    from <- res$from[1:n]
    to <- res$to[1:n]
    if(!simplify)
      {
        from <- from[res$flag]
        to <- to[res$flag]
        ordr2 <- order(ordr)
        from <- from[ordr2]
        to <- to[ordr2]
      }
    
    return(as.segSet(cbind(from,to)))
  }

"&.segSet" <- and.segSet <- function(a,b=NULL,...)
  {
    if(is.null(b))
      {
        deb <- max(a[,1])
        fin <- min(a[,2])
        if(deb<= fin)
          return(as.segSet(deb,fin))
        else
          return(as.segSet(NULL))
      }

    a <- or.segSet(a)
    b <- or.segSet(b)
    
    orda <- order(a[,1])
    ordb <- order(b[,1])

    
    res <- .C("intersection",
              from0=double(nrow(a)+nrow(b)),
              from1=as.double(a[orda,1]),
              from2=as.double(b[ordb,1]),
              to0=double(nrow(a)+nrow(b)),
              to1=as.double(a[orda,2]),
              to2=as.double(b[ordb,2]),
              n1=as.integer(nrow(a)),
              n2=as.integer(nrow(b)),
              dup=FALSE,
              PACKAGE="GeneR"
              )
    n <- res$n1
    from <- res$from0[1:n]
    to <- res$to0[1:n]
    return(as.segSet(cbind(from,to)))
 
  }


"-.segSet" <- not.segSet <- function(a,b)
  {
    a <- or.segSet(a)
    c <- and.segSet(a,b)
    c <- xorRecouvr(c,a)
    return(as.segSet(c))
  }


Xor.segSet <- function(a,b)
  {
    u <- or.segSet(a,b)
    c <- and.segSet(a,b)
    c <- xorRecouvr(c,u)
    return(as.segSet(c))
  }


#match <- function(...)
#  UseMethod("match")

#match.default <- function(...)
#  base::match(...)

Match <- function(x,a) 
{
  
 .C("num_in_interv",
    num=as.double(x),
    from=as.double(a[,1]),
    to=as.double(a[,2]),
    m=as.integer(length(x)),
    n=as.integer(nrow(a)),
    res=integer(length(x)),
    PACKAGE="GeneR")$res
}
